@@ -80,11 +80,11 @@ class Data(object):
         return Data.Base_pool[base_id].new() if base_id in Data.Base_pool else None
 
     @staticmethod
-    def create(table, colums, show_sql=False,base_id='default',show_manager_id=False):
+    def create(table, colums, comment='',show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
 
-        return Data.Base_pool[base_id].create(table, colums, show_sql) if base_id in Data.Base_pool else None
+        return Data.Base_pool[base_id].create(table, colums, comment,show_sql) if base_id in Data.Base_pool else None
 
     @staticmethod
     def insert(table, params, is_commit=True, show_sql=False,base_id='default',show_manager_id=False):
@@ -157,7 +157,7 @@ class Data(object):
         table_index = {}
         for i in all_table:
             table_name = i[0]
-            res = Data.query('desc '+str(table_name),base_id=base_id)
+            res = Data.query('show full columns from '+str(table_name),base_id=base_id)
             table_index[table_name] = list(res)
 
         base_manager = Data.Base_pool[base_id]
